==> savane-1.0.3.1.tar.gz: savane/frontend/php/account/lostpw-confirm.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: lostpw-confirm.php,v 1.19 2004/02/10 15:59:45 toddy Exp $
#
#
# Copyright 1999-2000 (c) The SourceForge Crew
#
#
#  Copyright (C) 2000-2003 Free Software Foundation
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
#
#
#

require "../include/pre.php";    


# CERN_SPECIFIC: here we also have a speech about AFS which must not be
# hardcoded
if ($GLOBALS['sys_use_pamauth'] == "yes") {
  db_query("SELECT user_pw FROM user WHERE user_name='$form_loginname'");
  $row_pw = db_fetch_array();
  if ($row_pw[user_pw] == 'PAM') {
    $HTML->header(array('title'=>"Lost Password Confirmation"));
    print "<p>This account uses an AFS password. <b>You cannot change your
           AFS password via Savannah</b>. Contact the AFS managers.";
    $HTML->footer(array());
    exit;
  }
}
# CERN_SPECIFIC

$confirm_hash = md5($session_hash . strval(time()) . strval(rand()));

$res_user = db_query("SELECT * FROM user WHERE user_name='$form_loginname'");
if (db_numrows($res_user) < 1) exit_error("Invalid User","That user does not exist.");
$row_user = db_fetch_array($res_user);

db_query("UPDATE user SET confirm_hash='$confirm_hash' WHERE user_id=$row_user[user_id]");

$message = sprintf(_("Someone (presumably you) on the %s site requested a password change through email verification."),$GLOBALS['sys_default_domain']);
$message .= _("If this was not you, this could pose a security risk for the system.")."\n\n";
$message .= sprintf(_("The request came from %s"),gethostbyaddr($GLOBALS['REMOTE_ADDR']))."\n";
$message .= '(IP: '.$GLOBALS['REMOTE_ADDR'].' port: '.$GLOBALS['REMOTE_PORT'].')\n';
$message .= _("with").' '.$GLOBALS['HTTP_USER_AGENT']."\n\n";
$message .= _("If you requested this verification, visit the same URL\nto change your password:")."\n\n";
$message .= $GLOBALS['sys_https_url'] . "/account/lostlogin.php?confirm_hash=".$confirm_hash."\n\n";
$message .= sprintf(_("If you did not request this verification, please visit this URL to report about it to %s"),$GLOBALS['sys_email_adress'])."\n\n";
$message .= _("In any case make sure that you do not disclose this url to\n sombody else, e.g. do not mail this to a public mailinglist!\n\n");
$message .= sprintf(_("-- the %s team."),$GLOBALS['sys_name'])."\n";

# We should not add i18n to admin messages
$message_for_admin = 
	"Someone attempted to change a password via email verification\n"
	. "on ".$GLOBALS['sys_default_domain']."\n\n"
	. "Someone is maybe trying to steal a user account.\n\n"
	. "The user concerned is ".$form_loginname."\n\n"
	. "The request comes from ".gethostbyaddr($GLOBALS['REMOTE_ADDR'])." "
	. "(IP: ".$GLOBALS['REMOTE_ADDR']." port: ".$GLOBALS['REMOTE_PORT'].") "
	. "with ".$GLOBALS['HTTP_USER_AGENT']."\n\n"
	. "RFC 822 (updated by RFC 1123) date:\n"
	. gmdate('D, d M Y H:i:s \G\M\T')
	. "\n";
	
	sendmail_mail($GLOBALS['sys_replyto']."@".$GLOBALS['sys_lists_domain'],
		      $row_user['email'],
		      $GLOBALS['sys_default_domain']." Verification",
		      $message);

	sendmail_mail($GLOBALS['sys_replyto']."@".$GLOBALS['sys_lists_domain'],
		      $GLOBALS['sys_email_adress'],
		      "password change - ".$GLOBALS['sys_default_domain'],
		      $message_for_admin,
		      0,
		      "lostpw");

$HTML->header(array('title'=>_("Lost Password Confirmation")));

echo '<h3>'._("Confirmation mailed").'</h3>';

echo '<p>'._("An email has been sent to the address you have on file.").'</p>';
echo '<p>'._("Follow the instructions in the email to change your account password.").'</p>';

echo '<p><a href="'.$GLOBALS['sys_home'].'">[ '._("Home").' ]</a></p>';

$HTML->footer(array());

?>

==> savane-1.0.4.tar.gz: savane/frontend/php/account/lostpw-confirm.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: lostpw-confirm.php,v 1.21 2004/09/23 12:16:34 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#
#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

require "../include/pre.php";    


# CERN_SPECIFIC: here we also have a speech about AFS which must not be
# hardcoded
if ($GLOBALS['sys_use_pamauth'] == "yes") {
  db_query("SELECT user_pw FROM user WHERE user_name='$form_loginname'");
  $row_pw = db_fetch_array();
  if ($row_pw[user_pw] == 'PAM') {
    $HTML->header(array('title'=>"Lost Password Confirmation"));
    print "<p>This account uses an AFS password. <b>You cannot change your
           AFS password via Savannah</b>. Contact the AFS managers.";
    $HTML->footer(array());
    exit;
  }
}
# CERN_SPECIFIC

$confirm_hash = md5($session_hash . strval(time()) . strval(rand()));

$res_user = db_query("SELECT * FROM user WHERE user_name='$form_loginname'");
if (db_numrows($res_user) < 1) exit_error("Invalid User","That user does not exist.");
$row_user = db_fetch_array($res_user);

db_query("UPDATE user SET confirm_hash='$confirm_hash' WHERE user_id=$row_user[user_id]");

$message = sprintf(_("Someone (presumably you) on the %s site requested a password change through email verification."),$GLOBALS['sys_default_domain']);
$message .= _("If this was not you, this could pose a security risk for the system.")."\n\n";
$message .= sprintf(_("The request came from %s"),gethostbyaddr($GLOBALS['REMOTE_ADDR']))."\n";
$message .= '(IP: '.$GLOBALS['REMOTE_ADDR'].' port: '.$GLOBALS['REMOTE_PORT'].')\n';
$message .= _("with").' '.$GLOBALS['HTTP_USER_AGENT']."\n\n";
$message .= _("If you requested this verification, visit the same URL\nto change your password:")."\n\n";
$message .= $GLOBALS['sys_https_url'].$GLOBALS['sys_home']."account/lostlogin.php?confirm_hash=".$confirm_hash."\n\n";
$message .= sprintf(_("If you did not request this verification, please visit this URL to report about it to %s"),$GLOBALS['sys_email_adress'])."\n\n";
$message .= _("In any case make sure that you do not disclose this url to\n sombody else, e.g. do not mail this to a public mailinglist!\n\n");
$message .= sprintf(_("-- the %s team."),$GLOBALS['sys_name'])."\n";

# We should not add i18n to admin messages
$message_for_admin = 
	"Someone attempted to change a password via email verification\n"
	. "on ".$GLOBALS['sys_default_domain']."\n\n"
	. "Someone is maybe trying to steal a user account.\n\n"
	. "The user concerned is ".$form_loginname."\n\n"
	. "The request comes from ".gethostbyaddr($GLOBALS['REMOTE_ADDR'])." "
	. "(IP: ".$GLOBALS['REMOTE_ADDR']." port: ".$GLOBALS['REMOTE_PORT'].") "
	. "with ".$GLOBALS['HTTP_USER_AGENT']."\n\n"
	. "RFC 822 (updated by RFC 1123) date:\n"
	. gmdate('D, d M Y H:i:s \G\M\T')
	. "\n";
	
	sendmail_mail($GLOBALS['sys_mail_replyto']."@".$GLOBALS['sys_mail_domain'],
		      $row_user['email'],
		      $GLOBALS['sys_default_domain']." Verification",
		      $message);

	sendmail_mail($GLOBALS['sys_mail_replyto']."@".$GLOBALS['sys_mail_domain'],
		      $GLOBALS['sys_mail_admin']."@".$GLOBALS['sys_mail_domain'],
		      "password change - ".$GLOBALS['sys_default_domain'],
		      $message_for_admin,
		      0,
		      "lostpw");

$HTML->header(array('title'=>_("Lost Password Confirmation")));

echo '<h3>'._("Confirmation mailed").'</h3>';

echo '<p>'._("An email has been sent to the address you have on file.").'</p>';
echo '<p>'._("Follow the instructions in the email to change your account password.").'</p>';

echo '<p><a href="'.$GLOBALS['sys_home'].'">[ '._("Home").' ]</a></p>';

$HTML->footer(array());

?>
